@@ -43,7 +43,10 @@
 #include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs.h>
 
-#include <linux/cdrom.h>
+#ifdef HAVE_HAL
+#include <libhal.h>
+#include <dbus/dbus.h>
+#endif
 
 #include "totem-disc.h"
 
@@ -52,8 +55,9 @@ typedef struct _CdCache {
   char *device, *mountpoint;
   GnomeVFSDrive *drive;
 
-  /* file descriptor to the device */
-  int fd;
+#ifdef HAVE_HAL
+  LibHalContext *ctx;
+#endif
 
   /* capabilities of the device */
   int cap;
@@ -233,6 +237,47 @@ cd_cache_get_dev_from_drives (GnomeVFSVolumeMonitor *mon, const char *device,
   return found;
 }
 
+#ifdef HAVE_HAL_0_2
+static LibHalContext *
+cd_cache_new_hal_ctx (void)
+{
+  LibHalContext *ctx;
+
+  ctx = hal_initialize (NULL, FALSE);
+
+  return ctx;
+}
+#elif HAVE_HAL_0_5
+static LibHalContext *
+cd_cache_new_hal_ctx (void)
+{
+  LibHalContext *ctx;
+  DBusConnection *conn;
+  DBusError error;
+
+  ctx = libhal_ctx_new ();
+  if (ctx == NULL)
+    return NULL;
+
+  dbus_error_init (&error);
+  conn = dbus_bus_get (DBUS_BUS_SYSTEM, &error);
+  if (conn != NULL && !dbus_error_is_set (&error)) {
+    libhal_ctx_set_dbus_connection (ctx, conn);
+    return ctx;
+  }
+
+  if (dbus_error_is_set (&error)) {
+    g_warning ("Couldn't get the system D-Bus: %s", error.message);
+    dbus_error_free (&error);
+  }
+
+  libhal_ctx_shutdown (ctx, NULL);
+  libhal_ctx_free(ctx);
+
+  return NULL;
+}
+#endif
+
 static CdCache *
 cd_cache_new (const char *dev,
 	      GError     **error)
@@ -241,6 +286,9 @@ cd_cache_new (const char *dev,
   char *mountpoint = NULL, *device, *local;
   GnomeVFSVolumeMonitor *mon;
   GnomeVFSDrive *drive = NULL;
+#ifdef HAVE_HAL
+  LibHalContext *ctx = NULL;
+#endif
   gboolean found;
 
   if (g_str_has_prefix (dev, "file://") != FALSE)
@@ -253,13 +301,12 @@ cd_cache_new (const char *dev,
   if (g_file_test (local, G_FILE_TEST_IS_DIR) != FALSE) {
     cache = g_new0 (CdCache, 1);
     cache->mountpoint = local;
-    cache->fd = -1;
     cache->is_media = FALSE;
 
     return cache;
   }
 
-  /* retrieve mountpoint (/etc/fstab) */
+  /* retrieve mountpoint from gnome-vfs volumes and drives */
   device = get_device (local, error);
   g_free (local);
   if (!device)
@@ -273,93 +320,133 @@ cd_cache_new (const char *dev,
 
   if (!found) {
     g_set_error (error, 0, 0,
-	_("Failed to find mountpoint for device %s in /etc/fstab"),
+	_("Failed to find mountpoint for device %s"),
 	device);
     return NULL;
   }
 
+#ifdef HAVE_HAL
+  ctx = cd_cache_new_hal_ctx ();
+  if (!ctx) {
+    g_set_error (error, 0, 0,
+	_("Could not connect to the HAL daemon"));
+    return NULL;
+  }
+#endif
+
   /* create struture */
   cache = g_new0 (CdCache, 1);
   cache->device = device;
   cache->mountpoint = mountpoint;
-  cache->fd = -1;
   cache->self_mounted = FALSE;
   cache->drive = drive;
   cache->is_media = TRUE;
+#ifdef HAVE_HAL
+  cache->ctx = ctx;
+#endif
 
   return cache;
 }
 
+#ifndef HAVE_HAL
+static gboolean
+cd_cache_has_medium (CdCache *cache)
+{
+  return FALSE;
+}
+#endif
+
+#ifdef HAVE_HAL_0_5
+static gboolean
+cd_cache_has_medium (CdCache *cache)
+{
+  char **devices;
+  int num_devices;
+  char *udi;
+  gboolean retval = FALSE;
+  DBusError error;
+
+  if (cache->drive == NULL)
+    return FALSE;
+
+  udi = gnome_vfs_drive_get_hal_udi (cache->drive);
+  if (udi == NULL)
+    return FALSE;
+
+  dbus_error_init (&error);
+  devices = libhal_manager_find_device_string_match (cache->ctx,
+      "info.parent", udi, &num_devices, &error);
+  if (devices != NULL && num_devices >= 1)
+    retval = TRUE;
+
+  if (dbus_error_is_set (&error)) {
+    g_warning ("Error getting the children: %s", error.message);
+    dbus_error_free (&error);
+    g_free (udi);
+    return FALSE;
+  }
+
+  if (retval == FALSE) {
+    dbus_bool_t volume;
+
+    volume = libhal_device_get_property_bool (cache->ctx,
+	udi, "volume.is_disc", &error);
+    if (dbus_error_is_set (&error)) {
+      g_warning ("Error checking whether the volume is a disc: %s",
+	  error.message);
+      dbus_error_free (&error);
+      g_free (udi);
+      return FALSE;
+    }
+    retval = TRUE;
+  }
+
+  if (devices != NULL)
+    libhal_free_string_array (devices);
+  g_free (udi);
+
+  return retval;
+}
+#elif HAVE_HAL_0_2
+static gboolean
+cd_cache_has_medium (CdCache *cache)
+{
+  char **devices;
+  int num_devices;
+  char *udi;
+  gboolean retval = FALSE;
+
+  if (cache->drive == NULL)
+    return FALSE;
+ 
+  udi = gnome_vfs_drive_get_hal_udi (cache->drive);
+  if (udi == NULL)
+    return FALSE;
+
+  devices = hal_manager_find_device_string_match (cache->ctx,
+      "info.parent", udi, &num_devices);
+  if (devices != NULL && num_devices >= 1)
+    retval = TRUE;
+
+  hal_free_string_array (devices);
+  g_free (udi);
+
+  return retval;
+}
+#endif
+
 static gboolean
 cd_cache_open_device (CdCache *cache,
 		      GError **error)
 {
-  int drive, err;
-
   /* not a medium? */
   if (cache->is_media == FALSE) {
-    cache->cap = CDC_DVD;
     return TRUE;
   }
 
-  /* already open? */
-  if (cache->fd > 0)
-    return TRUE;
-
-  /* try to open the CD before creating anything */
-  if ((cache->fd = open (cache->device, O_RDONLY)) < 0) {
-    err = errno;
-    if (err == ENOMEDIUM) {
-      g_set_error (error, 0, 0,
-          _("Please check that a disc is present in the drive."));
-    } else {
-      g_set_error (error, 0, 0,
-          _("Failed to open device %s for reading: %s"),
-        cache->device, g_strerror (err));
-    }
-    return FALSE;
-  }
-
-  /* get capabilities */
-  if ((cache->cap = ioctl (cache->fd, CDROM_GET_CAPABILITY, NULL)) < 0) {
-    close (cache->fd);
-    cache->fd = -1;
+  if (cd_cache_has_medium (cache) == FALSE) {
     g_set_error (error, 0, 0,
-        _("Failed to retrieve capabilities of device %s: %s"),
-        cache->device, g_strerror (errno));
-    return FALSE;
-  }
-
-  /* is there a disc in the tray? */
-  if ((drive = ioctl (cache->fd, CDROM_DRIVE_STATUS, NULL)) != CDS_DISC_OK) {
-    const char *drive_s;
-
-    close (cache->fd);
-    cache->fd = -1;
-
-    switch (drive) {
-      case CDS_NO_INFO:
-        drive_s = "Not implemented";
-        break;
-      case CDS_NO_DISC:
-        drive_s = "No disc in tray";
-        break;
-      case CDS_TRAY_OPEN:
-        drive_s = "Tray open";
-        break;
-      case CDS_DRIVE_NOT_READY:
-        drive_s = "Drive not ready";
-        break;
-      case CDS_DISC_OK:
-        drive_s = "OK";
-        break;
-      default:
-        drive_s = "Unknown";
-        break;
-    }
-    g_set_error (error, 0, 0,
-        _("Drive status 0x%x (%s) - check disc"),
-        drive, drive_s);
+	_("Please check that a disc is present in the drive."));
     return FALSE;
   }
 
@@ -456,10 +543,16 @@ cd_cache_free (CdCache *cache)
     while (!called) g_main_iteration (TRUE);
   }
 
-  /* close file descriptor to device */
-  if (cache->fd > 0) {
-    close (cache->fd);
+#ifdef HAVE_HAL
+  if (cache->ctx != NULL) {
+#ifdef HAVE_HAL_0_5
+    libhal_ctx_shutdown (cache->ctx, NULL);
+    libhal_ctx_free(cache->ctx);
+#elif HAVE_HAL_0_2
+    hal_shutdown (cache->ctx);
+#endif
   }
+#endif /* HAVE_HAL */
 
   /* free mem */
   if (cache->drive)
@@ -474,52 +567,24 @@ cd_cache_disc_is_cdda (CdCache *cache,
 		       GError **error)
 {
   MediaType type = MEDIA_TYPE_DATA;
-  int disc;
-  const char *disc_s;
+  GList *vol, *item;
 
   /* We can't have audio CDs on disc, yet */
   if (cache->is_media == FALSE)
     return type;
 
-  /* open disc and open mount */
-  if (!cd_cache_open_device (cache, error))
-    return MEDIA_TYPE_ERROR;
-
-  if ((disc = ioctl (cache->fd, CDROM_DISC_STATUS, NULL)) < 0) {
-    g_set_error (error, 0, 0,
-        _("Error getting %s disc status: %s"),
-        cache->device, g_strerror (errno));
-    return MEDIA_TYPE_ERROR;
-  }
-
-  switch (disc) {
-    case CDS_NO_INFO:
-      /* The drive doesn't implement CDROM_DISC_STATUS */
-      break;
-    case CDS_NO_DISC:
-      disc_s = "No disc in tray";
-      type = MEDIA_TYPE_ERROR;
-      break;
-    case CDS_AUDIO:
-    case CDS_MIXED:
+  for (vol = item = gnome_vfs_drive_get_mounted_volumes (cache->drive);
+      item != NULL; item = item->next) {
+    char *mnt = gnome_vfs_volume_get_activation_uri (item->data);
+    if (mnt && strncmp (mnt, "cdda://", 7) == 0) {
+      g_free (mnt);
       type = MEDIA_TYPE_CDDA;
       break;
-    case CDS_DATA_1:
-    case CDS_DATA_2:
-    case CDS_XA_2_1:
-    case CDS_XA_2_2:
-      break;
-    default:
-      disc_s = "Unknown";
-      type = MEDIA_TYPE_ERROR;
-      break;
-  }
-  if (type == MEDIA_TYPE_ERROR) {
-    g_set_error (error, 0, 0,
-        _("Unexpected/unknown cd type 0x%x (%s)"),
-        disc, disc_s);
-    return MEDIA_TYPE_ERROR;
+    }
+    g_free (mnt);
   }
+  g_list_foreach (vol, (GFunc) gnome_vfs_volume_unref, NULL);
+  g_list_free (vol);
 
   return type;
 }
@@ -599,8 +664,6 @@ cd_cache_disc_is_dvd (CdCache *cache,
   /* open disc, check capabilities and open mount */
   if (!cd_cache_open_device (cache, error))
     return MEDIA_TYPE_ERROR;
-  if (!(cache->cap & CDC_DVD))
-    return MEDIA_TYPE_DATA;
   if (!cd_cache_open_mountpoint (cache, error))
     return MEDIA_TYPE_ERROR;
   if (!cache->mountpoint)
