@@ -1934,7 +1934,9 @@ on_help_activate (GtkButton *button, Totem *totem)
 static void
 on_about1_activate (GtkButton *button, Totem *totem)
 {
-	GdkPixbuf *pixbuf = NULL;
+	char *backend_version, *description;
+	const char *frontend_type;
+
 	const char *authors[] =
 	{
 		"Bastien Nocera <hadess@hadess.net>",
@@ -1948,9 +1950,6 @@ on_about1_activate (GtkButton *button, Totem *totem)
 		"Chee Bin Hoh <cbhoh@gnome.org>",
 		NULL
 	};
-	const char *frontend_type;
-	char *backend_version, *description;
-	char *filename;
 
 	if (totem->about != NULL)
 	{
@@ -1958,11 +1957,6 @@ on_about1_activate (GtkButton *button, Totem *totem)
 		return;
 	}
 
-	filename = g_build_filename (DATADIR,
-			"totem", "media-player-48.png", NULL);
-	pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
-	g_free (filename);
-
 #ifdef HAVE_GTK_ONLY
 	frontend_type = N_("GTK+");
 #else
@@ -1973,26 +1967,22 @@ on_about1_activate (GtkButton *button, Totem *totem)
 	/* This lists the back-end and front-end types and versions, such as
 	 * Movie Player using GStreamer 0.10.1 and GNOME */
 	description = g_strdup_printf (_("Movie Player using %s and %s"),
-				backend_version, _(frontend_type));
+				       backend_version, _(frontend_type));
 
 	totem->about = g_object_new (GTK_TYPE_ABOUT_DIALOG,
-			"name", _("Totem"),
-			"version", VERSION,
-			"copyright", _("Copyright \xc2\xa9 2002-2005 Bastien Nocera"),
-			"comments", description,
-			"authors", authors,
-			"documenters", documenters,
-			"artists", artists, 
-			"translator-credits", _("translator-credits"),
-			"logo", pixbuf,
-			NULL);
+				     "version", PACKAGE_VERSION,
+				     "copyright", _("Copyright \xc2\xa9 2002-2006 Bastien Nocera"),
+				     "comments", description,
+				     "authors", authors,
+				     "documenters", documenters,
+				     "artists", artists,
+				     "translator-credits", _("translator-credits"),
+				     "logo-icon-name", "media-player-48",
+				     NULL);
 
 	g_free (backend_version);
 	g_free (description);
 
-	if (pixbuf != NULL)
-		gdk_pixbuf_unref (pixbuf);
-
 	g_object_add_weak_pointer (G_OBJECT (totem->about),
 			(gpointer *)&totem->about);
 	gtk_window_set_transient_for (GTK_WINDOW (totem->about),
@@ -3508,6 +3498,7 @@ totem_volume_create (void)
 
 	widget = bacon_volume_button_new (GTK_ICON_SIZE_SMALL_TOOLBAR,
 					  0, 100, 1);
+	gtk_widget_set_sensitive (widget, FALSE);
 	gtk_widget_show (widget);
 
 	return widget;
@@ -3517,7 +3508,6 @@ int
 main (int argc, char **argv)
 {
 	Totem *totem;
-	char *filename;
 	GConfClient *gc;
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
@@ -3536,7 +3526,7 @@ main (int argc, char **argv)
 #ifdef HAVE_GTK_ONLY
 	gtk_init (&argc, &argv);
 #else
-	gnome_program_init ("totem", VERSION,
+	gnome_program_init ("totem", PACKAGE_VERSION,
 			LIBGNOMEUI_MODULE,
 			argc, argv,
 			GNOME_PARAM_APP_DATADIR, DATADIR,
@@ -3545,6 +3535,7 @@ main (int argc, char **argv)
 #endif /* HAVE_GTK_ONLY */
 
 	g_set_application_name (_("Totem Movie Player"));
+	gtk_window_set_default_icon_name ("media-player-48");
 
 	gnome_vfs_init ();
 
@@ -3590,10 +3581,7 @@ main (int argc, char **argv)
 		totem_action_exit (NULL);
 
 	totem->win = glade_xml_get_widget (totem->xml, "totem_main_window");
-	filename = totem_interface_get_full_path ("media-player-48.png");
-	gtk_window_set_default_icon_from_file (filename, NULL);
-	g_free (filename);
-
+	
 	totem_named_icons_init (totem, FALSE);
 
 	/* The sidebar */
@@ -3652,6 +3640,7 @@ main (int argc, char **argv)
 	/* Show ! (again) the video widget this time. */
 	video_widget_create (totem);
 	long_action ();
+	gtk_widget_grab_focus (GTK_WIDGET (totem->bvw));
 
 	/* The prefs after the video widget is connected */
 	totem_setup_preferences (totem);
